---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Created config.json
2. Created products.json
3. Run this command: ...
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**(please complete the following information):**
 - OS: [e.g. iOS]
- content of products.json
```json
[
  {
    "url": "...",
    "warn_price": 345 
  },
  {
    "url": "...",
    "warn_price": 543.4
  }
]
```
